NaMaster: nmt_master_calculator Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_master_calculator Struct Reference

`#include <namaster.h>`

## Data Fields
int | lmax
int | lmax_mask
int | npcl
int | s1
int | s2
int | has_00
flouble *** | xi_00
int | has_0s
flouble **** | xi_0s
int | has_ss
flouble **** | xi_pp
flouble **** | xi_mm
int | pure_e1
int | pure_e2
int | pure_b1
int | pure_b2
int | pure_any
int | npure_0s
int | npure_ss

## Field Documentation

int nmt_master_calculator::has_00

int nmt_master_calculator::has_0s

int nmt_master_calculator::has_ss

int nmt_master_calculator::lmax

int nmt_master_calculator::lmax_mask

int nmt_master_calculator::npcl

int nmt_master_calculator::npure_0s

int nmt_master_calculator::npure_ss

int nmt_master_calculator::pure_any

int nmt_master_calculator::pure_b1

int nmt_master_calculator::pure_b2

int nmt_master_calculator::pure_e1

int nmt_master_calculator::pure_e2

int nmt_master_calculator::s1

int nmt_master_calculator::s2

flouble*** nmt_master_calculator::xi_00

flouble**** nmt_master_calculator::xi_0s

flouble**** nmt_master_calculator::xi_mm

flouble**** nmt_master_calculator::xi_pp

The documentation for this struct was generated from the following file:

- namaster.h